@@ -4,6 +4,8 @@
 
 // Dialog Styles
 
+
+
 #[cfg(windows)]
 /// Don't show any icons
 pub const DIALOGSTYLE_NONE: windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_STYLE =
@@ -117,3 +119,10 @@ pub const WINDOWSTYLE_NOCAPTION: gtk::WindowType = gtk::WindowType::Popup;
 pub const ADVANCED_WINDOWSTYLE_UTILITY: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_EX_TOOLWINDOW;
 #[cfg(unix)]
 pub const ADVANCED_WINDOWSTYLE_UTILITY: gtk::gdk::WindowTypeHint = gtk::gdk::WindowTypeHint::Utility;
+
+/// File Chooser Attributes
+pub const FC_NONE:winapi::shared::minwindef::DWORD = 0;
+pub const FC_DISABLE_READ_ONLY:winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_HIDEREADONLY;
+/// Windows Only
+pub const FC_NEW_EXPLORER:winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_EXPLORER;
+pub const FC_ENABLE_HELP:winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_SHOWHELP;
