@@ -4,8 +4,6 @@ use crate::io::storage::Storage;
 
 pub mod dialog;
 
-//default not found
-
 #[cfg(windows)]
 #[derive(Clone)]
 pub struct Frame {
@@ -17,6 +15,7 @@ pub struct Frame {
 impl Frame {
     /// Create a new Frame
     pub fn new(window: windows_sys::Win32::Foundation::HWND) -> Self {
+        info!("A window has been created. handle: {}",window);
         Self {
             handle: window
         }
@@ -26,28 +25,40 @@ impl Frame {
     pub fn show(&self) {
         use windows_sys::Win32::UI::WindowsAndMessaging::ShowWindow;
         use windows_sys::Win32::UI::WindowsAndMessaging::SW_SHOWNORMAL;
-        unsafe { ShowWindow(self.handle,SW_SHOWNORMAL); }
+        unsafe {
+            ShowWindow(self.handle,SW_SHOWNORMAL);
+            info!("A window has appeared. handle: {}",self.handle);
+        }
     }
 
     /// Maximize the window
     pub fn show_maximized(&self) {
         use windows_sys::Win32::UI::WindowsAndMessaging::ShowWindow;
         use windows_sys::Win32::UI::WindowsAndMessaging::SW_MAXIMIZE;
-        unsafe { ShowWindow(self.handle,SW_MAXIMIZE); }
+        unsafe {
+            ShowWindow(self.handle,SW_MAXIMIZE);
+            info!("The window has been maximized. handle: {}",self.handle);
+        }
     }
 
     /// Minimize the window
     pub fn show_minimized(&self) {
         use windows_sys::Win32::UI::WindowsAndMessaging::ShowWindow;
         use windows_sys::Win32::UI::WindowsAndMessaging::SW_MINIMIZE;
-        unsafe { ShowWindow(self.handle,SW_MINIMIZE); }
+        unsafe {
+            ShowWindow(self.handle,SW_MINIMIZE);
+            info!("The window has been minimized. handle: {}",self.handle);
+        }
     }
 
     /// Hide the window
     pub fn hide(&self) {
         use windows_sys::Win32::UI::WindowsAndMessaging::ShowWindow;
         use windows_sys::Win32::UI::WindowsAndMessaging::SW_HIDE;
-        unsafe { ShowWindow(self.handle,SW_HIDE); }
+        unsafe {
+            ShowWindow(self.handle,SW_HIDE);
+            info!("The window has been hidden. handle: {}",self.handle);
+        }
     }
 
     /// Returns the window handle.
@@ -60,6 +71,7 @@ impl Frame {
         use windows_sys::Win32::UI::WindowsAndMessaging::SetWindowTextA;
         unsafe {
             SetWindowTextA(self.handle,title.as_ptr() as _);
+            info!("The title of the window has been changed to '{}'. handle: {}",title,self.handle);
         }
     }
 
@@ -186,6 +198,7 @@ pub struct Frame {
 impl Frame {
     /// Create a new Frame
     pub fn new(window: gtk::Window) -> Self {
+        info!("A window has been created. handle: {}",window);
         Self {
             handle: window
         }
@@ -195,30 +208,35 @@ impl Frame {
     pub fn show(&self) {
         use gtk::prelude::*;
         self.handle.show();
+        info!("A window has appeared. handle: {}",self.handle);
     }
 
     /// Maximize the window
     pub fn show_maximized(&self) {
         use gtk::prelude::*;
         self.handle.maximize();
+        info!("The window has been maximized. handle: {}",self.handle);
     }
 
     /// Minimize the window
     pub fn show_minimized(&self) {
         use gtk::prelude::*;
         self.handle.unmaximize();
+        info!("The window has been minimized handle: {}",self.handle);
     }
 
     /// Hide the window
     pub fn hide(&self) {
         use gtk::prelude::*;
         self.handle.hide();
+        info!("The window has been hidden. handle: {}",self.handle)
     }
 
     /// Set window title
     pub fn set_title(&self,title: String) {
         use gtk::prelude::*;
         self.handle.set_title(title.as_str());
+        info!("The title of the window has been changed to '{}'. handle: {}",title,self.handle);
     }
 
     /// Returns the window handle.
